from pymcq.mcqtypes import create_usual_question, create_usual_part
from pymcq.mcqtex import latex_format

from random import randrange


TITLE = "voce"


def generate_question():

    get_part_list = (__get_part_masa_jabuka,
                     __get_part_jabuka_postotak)

    return create_usual_question(TITLE, __generate_parameters,
                                 __get_main_text, get_part_list)


def __get_main_text(parameters):

    broj_jabuka, broj_krusaka = parameters[:2]
    masa_jabuke, masa_kruske = map(latex_format, parameters[2:])

    main_text = r'''
    U kosari ima tocno %s jabuka i %s krusaka. Ako je masa jedne jabuke
    $%s\;\mathrm{kg}$, a masa jedne kruske $%s\;\mathrm{kg}$ odredite:
    ''' % (broj_jabuka, broj_krusaka, masa_jabuke, masa_kruske)

    return main_text


def __calculate_masa_jabuka(parameters):
    broj_jabuka, _, masa_jabuke, _ = parameters
    return broj_jabuka * masa_jabuke


def __get_part_masa_jabuka(parameters):

    answer = __calculate_masa_jabuka(parameters)

    points = 1.0

    text = r'''(1 bod)
    ukupnu masu jabuka u kosari u kilogramima:'''

    return create_usual_part(text, answer, points)


def __calculate_postotak_jabuka(parameters):

    _, broj_krusaka, _, masa_kruske = parameters

    masa_jabuka = __calculate_masa_jabuka(parameters)

    masa_krusaka = broj_krusaka * masa_kruske

    return 100. * masa_jabuka / (masa_jabuka + masa_krusaka)


def __get_part_jabuka_postotak(parameters):

    answer = __calculate_postotak_jabuka(parameters)

    points = 1.0

    text = r"(1 bod) postotak $\%$ ukupne mase voca koju cine jabuke:"

    return create_usual_part(text, answer, points)


def __generate_parameters():
    broj_jabuka = randrange(5, 21)
    broj_krusaka = randrange(5, 21)

    masa_jabuke = randrange(10, 50) / 100.
    masa_kruske = randrange(10, 50) / 100.

    return broj_jabuka, broj_krusaka, masa_jabuke, masa_kruske



from pymcq import mcqjson
from pymcq import mcqtex
from pymcq.mcqtypes import TestInfo

from pymcq.examples.heavymath import question1
from pymcq.examples.heavymath import question2

QUESTIONS = question1, question2

COURSE = 'Teska matematika'
EXAM = 'Ispitni rok'
DATE = '11.09.2014.'
NOTE = r'''\textit{Za svaki krivo zacrnjen odgovor oduzima se 1/4 bodova
koje je moguce dobiti na zadanom pitanju. Ako su za isto pitanje zacrnjena
dva odgovora, zadatak se smatra nerijesenim i nosi 0 bodova.
}'''


if __name__ == '__main__':

    testinfo = TestInfo(COURSE, EXAM, DATE, NOTE)
    question_generators = [question.generate_question
                           for question in QUESTIONS]

    mcqjson.create_exam('student_list.csv', 'test.json',
                        testinfo, question_generators)
    mcqtex.create_test('test.json', 'test.tex')
    mcqtex.create_matrix('test.json', 'matrix.tex')



from pymcq.mcqtypes import create_usual_question, create_usual_part
from pymcq.mcqtex import latex_format

from random import randrange


TITLE = "minus_plus"


def generate_question():

    get_part_list = (__get_part_plus,
                     __get_part_minus)

    return create_usual_question(TITLE, __generate_parameters,
                                 __get_main_text, get_part_list)


def __get_main_text(parameters):
    x, y = map(latex_format, parameters)
    main_text = r'''
    Ako je $x = %s$, a $y = %s$, odredite iznose sljedecih izraza:
    ''' % (x, y)

    return main_text


def __get_part_plus(parameters):

    x, y = parameters

    answer = x + y

    points = 1.0

    text = r"(1 bod) $x + y$"

    return create_usual_part(text, answer, points)


def __get_part_minus(parameters):

    x, y = parameters

    answer = x - y

    points = 1.0

    text = r"(1 bod) $x - y$"

    return create_usual_part(text, answer, points)


def __generate_parameters():
    x = randrange(100) / 100. + randrange(20)
    y = randrange(1000000000) / 100. + randrange(20)

    return x, y
